@@ -4,11 +4,20 @@ use Email::Simple;
 # use 5.006;
 # use warnings;
 use strict;
-$Email::Abstract::VERSION = '2.133_03';
-use Module::Pluggable search_path => [__PACKAGE__], require => 1;
+$Email::Abstract::VERSION = '2.133_04';
+use Module::Pluggable
+  search_path => [__PACKAGE__],
+  except      => 'Email::Abstract::Plugin',
+  require     => 1;
 
 my @plugins = __PACKAGE__->plugins(); # Requires them.
-my %adapter_for = map { $_->target => $_ } @plugins;
+my %adapter_for =
+  map  { $_->target => $_ }
+  grep {
+    my $avail = eval { $_->is_available };
+    $@ ? ($@ =~ /Can't locate object method "is_available"/) : $avail;
+  }
+  @plugins;
 
 sub object {
   my ($self) = @_;
